pub struct PHAssetCollection { /* private fields */ }PHCollection and PHObject only.Expand description
Implementations
Sourceimpl PHAssetCollection
impl PHAssetCollection
Sourcepub unsafe fn assetCollectionType(&self) -> PHAssetCollectionType
Available on crate feature PhotosTypes only.
pub unsafe fn assetCollectionType(&self) -> PHAssetCollectionType
PhotosTypes only.Sourcepub unsafe fn assetCollectionSubtype(&self) -> PHAssetCollectionSubtype
Available on crate feature PhotosTypes only.
pub unsafe fn assetCollectionSubtype(&self) -> PHAssetCollectionSubtype
PhotosTypes only.Sourcepub unsafe fn estimatedAssetCount(&self) -> NSUInteger
pub unsafe fn estimatedAssetCount(&self) -> NSUInteger
Sourcepub unsafe fn approximateLocation(&self) -> Option<Retained<CLLocation>>
Available on crate feature objc2-core-location only.
pub unsafe fn approximateLocation(&self) -> Option<Retained<CLLocation>>
objc2-core-location only.Sourcepub unsafe fn localizedLocationNames(&self) -> Retained<NSArray<NSString>>
pub unsafe fn localizedLocationNames(&self) -> Retained<NSArray<NSString>>
pub unsafe fn fetchAssetCollectionsWithLocalIdentifiers_options( identifiers: &NSArray<NSString>, options: Option<&PHFetchOptions>, ) -> Retained<PHFetchResult<PHAssetCollection>>
PHFetchOptions and PHFetchResult only.pub unsafe fn fetchAssetCollectionsWithType_subtype_options( type: PHAssetCollectionType, subtype: PHAssetCollectionSubtype, options: Option<&PHFetchOptions>, ) -> Retained<PHFetchResult<PHAssetCollection>>
PHFetchOptions and PHFetchResult and PhotosTypes only.pub unsafe fn fetchAssetCollectionsContainingAsset_withType_options( asset: &PHAsset, type: PHAssetCollectionType, options: Option<&PHFetchOptions>, ) -> Retained<PHFetchResult<PHAssetCollection>>
PHAsset and PHFetchOptions and PHFetchResult and PhotosTypes only.pub unsafe fn fetchAssetCollectionsWithALAssetGroupURLs_options( asset_group_ur_ls: &NSArray<NSURL>, options: Option<&PHFetchOptions>, ) -> Retained<PHFetchResult<PHAssetCollection>>
PHFetchOptions and PHFetchResult only.pub unsafe fn fetchMomentsInMomentList_options( moment_list: &PHCollectionList, options: Option<&PHFetchOptions>, ) -> Retained<PHFetchResult<PHAssetCollection>>
PHFetchOptions and PHFetchResult only.pub unsafe fn fetchMomentsWithOptions( options: Option<&PHFetchOptions>, ) -> Retained<PHFetchResult<PHAssetCollection>>
PHFetchOptions and PHFetchResult only.pub unsafe fn transientAssetCollectionWithAssets_title( assets: &NSArray<PHAsset>, title: Option<&NSString>, ) -> Retained<PHAssetCollection>
PHAsset only.pub unsafe fn transientAssetCollectionWithAssetFetchResult_title( fetch_result: &PHFetchResult<PHAsset>, title: Option<&NSString>, ) -> Retained<PHAssetCollection>
PHAsset and PHFetchResult only.Methods from Deref<Target = PHCollection>
Sourcepub unsafe fn canContainAssets(&self) -> bool
pub unsafe fn canContainAssets(&self) -> bool
Sourcepub unsafe fn canContainCollections(&self) -> bool
pub unsafe fn canContainCollections(&self) -> bool
Sourcepub unsafe fn localizedTitle(&self) -> Option<Retained<NSString>>
pub unsafe fn localizedTitle(&self) -> Option<Retained<NSString>>
pub unsafe fn canPerformEditOperation( &self, an_operation: PHCollectionEditOperation, ) -> bool
PhotosTypes only.Methods from Deref<Target = PHObject>
Sourcepub unsafe fn localIdentifier(&self) -> Retained<NSString>
pub unsafe fn localIdentifier(&self) -> Retained<NSString>
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for PHAssetCollection
impl AsRef<AnyObject> for PHAssetCollection
Sourceimpl AsRef<NSObject> for PHAssetCollection
impl AsRef<NSObject> for PHAssetCollection
Sourceimpl AsRef<PHAssetCollection> for PHAssetCollection
impl AsRef<PHAssetCollection> for PHAssetCollection
Sourceimpl AsRef<PHAssetCollection> for PHProject
Available on crate feature PHProject only.
impl AsRef<PHAssetCollection> for PHProject
PHProject only.Sourcefn as_ref(&self) -> &PHAssetCollection
fn as_ref(&self) -> &PHAssetCollection
Sourceimpl AsRef<PHCollection> for PHAssetCollection
impl AsRef<PHCollection> for PHAssetCollection
Sourcefn as_ref(&self) -> &PHCollection
fn as_ref(&self) -> &PHCollection
Sourceimpl AsRef<PHObject> for PHAssetCollection
impl AsRef<PHObject> for PHAssetCollection
Sourceimpl Borrow<AnyObject> for PHAssetCollection
impl Borrow<AnyObject> for PHAssetCollection
Sourceimpl Borrow<NSObject> for PHAssetCollection
impl Borrow<NSObject> for PHAssetCollection
Sourceimpl Borrow<PHAssetCollection> for PHProject
Available on crate feature PHProject only.
impl Borrow<PHAssetCollection> for PHProject
PHProject only.Sourcefn borrow(&self) -> &PHAssetCollection
fn borrow(&self) -> &PHAssetCollection
Sourceimpl Borrow<PHCollection> for PHAssetCollection
impl Borrow<PHCollection> for PHAssetCollection
Sourcefn borrow(&self) -> &PHCollection
fn borrow(&self) -> &PHCollection
Sourceimpl Borrow<PHObject> for PHAssetCollection
impl Borrow<PHObject> for PHAssetCollection
Sourceimpl ClassType for PHAssetCollection
impl ClassType for PHAssetCollection
Sourceconst NAME: &'static str = "PHAssetCollection"
const NAME: &'static str = "PHAssetCollection"
Sourcetype Super = PHCollection
type Super = PHCollection
Sourcetype ThreadKind = <<PHAssetCollection as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<PHAssetCollection as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for PHAssetCollection
impl CopyingHelper for PHAssetCollection
Sourcetype Result = PHAssetCollection
type Result = PHAssetCollection
Self if the type has no
immutable counterpart. Read moreSourceimpl Debug for PHAssetCollection
impl Debug for PHAssetCollection
Sourceimpl Deref for PHAssetCollection
impl Deref for PHAssetCollection
Sourceimpl Hash for PHAssetCollection
impl Hash for PHAssetCollection
Sourceimpl Message for PHAssetCollection
impl Message for PHAssetCollection
Sourceimpl NSCopying for PHAssetCollection
impl NSCopying for PHAssetCollection
Sourceimpl NSObjectProtocol for PHAssetCollection
impl NSObjectProtocol for PHAssetCollection
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref