pub struct PHCollectionList { /* private fields */ }PHCollection and PHObject only.Expand description
Implementations
Sourceimpl PHCollectionList
impl PHCollectionList
Sourcepub unsafe fn collectionListType(&self) -> PHCollectionListType
Available on crate feature PhotosTypes only.
pub unsafe fn collectionListType(&self) -> PHCollectionListType
PhotosTypes only.Sourcepub unsafe fn collectionListSubtype(&self) -> PHCollectionListSubtype
Available on crate feature PhotosTypes only.
pub unsafe fn collectionListSubtype(&self) -> PHCollectionListSubtype
PhotosTypes only.Sourcepub unsafe fn localizedLocationNames(&self) -> Retained<NSArray<NSString>>
pub unsafe fn localizedLocationNames(&self) -> Retained<NSArray<NSString>>
pub unsafe fn fetchCollectionListsContainingCollection_options( collection: &PHCollection, options: Option<&PHFetchOptions>, ) -> Retained<PHFetchResult<PHCollectionList>>
PHFetchOptions and PHFetchResult only.pub unsafe fn fetchCollectionListsWithLocalIdentifiers_options( identifiers: &NSArray<NSString>, options: Option<&PHFetchOptions>, ) -> Retained<PHFetchResult<PHCollectionList>>
PHFetchOptions and PHFetchResult only.pub unsafe fn fetchCollectionListsWithType_subtype_options( collection_list_type: PHCollectionListType, subtype: PHCollectionListSubtype, options: Option<&PHFetchOptions>, ) -> Retained<PHFetchResult<PHCollectionList>>
PHFetchOptions and PHFetchResult and PhotosTypes only.pub unsafe fn fetchMomentListsWithSubtype_containingMoment_options( moment_list_subtype: PHCollectionListSubtype, moment: &PHAssetCollection, options: Option<&PHFetchOptions>, ) -> Retained<PHFetchResult<PHCollectionList>>
PHFetchOptions and PHFetchResult and PhotosTypes only.pub unsafe fn fetchMomentListsWithSubtype_options( moment_list_subtype: PHCollectionListSubtype, options: Option<&PHFetchOptions>, ) -> Retained<PHFetchResult<PHCollectionList>>
PHFetchOptions and PHFetchResult and PhotosTypes only.pub unsafe fn transientCollectionListWithCollections_title( collections: &NSArray<PHCollection>, title: Option<&NSString>, ) -> Retained<PHCollectionList>
pub unsafe fn transientCollectionListWithCollectionsFetchResult_title( fetch_result: &PHFetchResult<PHCollection>, title: Option<&NSString>, ) -> Retained<PHCollectionList>
PHFetchResult only.Methods from Deref<Target = PHCollection>
Sourcepub unsafe fn canContainAssets(&self) -> bool
pub unsafe fn canContainAssets(&self) -> bool
Sourcepub unsafe fn canContainCollections(&self) -> bool
pub unsafe fn canContainCollections(&self) -> bool
Sourcepub unsafe fn localizedTitle(&self) -> Option<Retained<NSString>>
pub unsafe fn localizedTitle(&self) -> Option<Retained<NSString>>
pub unsafe fn canPerformEditOperation( &self, an_operation: PHCollectionEditOperation, ) -> bool
PhotosTypes only.Methods from Deref<Target = PHObject>
Sourcepub unsafe fn localIdentifier(&self) -> Retained<NSString>
pub unsafe fn localIdentifier(&self) -> Retained<NSString>
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
Ivar::load instead.Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<AnyObject> for PHCollectionList
impl AsRef<AnyObject> for PHCollectionList
Sourceimpl AsRef<NSObject> for PHCollectionList
impl AsRef<NSObject> for PHCollectionList
Sourceimpl AsRef<PHCollection> for PHCollectionList
impl AsRef<PHCollection> for PHCollectionList
Sourcefn as_ref(&self) -> &PHCollection
fn as_ref(&self) -> &PHCollection
Sourceimpl AsRef<PHCollectionList> for PHCollectionList
impl AsRef<PHCollectionList> for PHCollectionList
Sourceimpl AsRef<PHObject> for PHCollectionList
impl AsRef<PHObject> for PHCollectionList
Sourceimpl Borrow<AnyObject> for PHCollectionList
impl Borrow<AnyObject> for PHCollectionList
Sourceimpl Borrow<NSObject> for PHCollectionList
impl Borrow<NSObject> for PHCollectionList
Sourceimpl Borrow<PHCollection> for PHCollectionList
impl Borrow<PHCollection> for PHCollectionList
Sourcefn borrow(&self) -> &PHCollection
fn borrow(&self) -> &PHCollection
Sourceimpl Borrow<PHObject> for PHCollectionList
impl Borrow<PHObject> for PHCollectionList
Sourceimpl ClassType for PHCollectionList
impl ClassType for PHCollectionList
Sourceconst NAME: &'static str = "PHCollectionList"
const NAME: &'static str = "PHCollectionList"
Sourcetype Super = PHCollection
type Super = PHCollection
Sourcetype ThreadKind = <<PHCollectionList as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<PHCollectionList as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl CopyingHelper for PHCollectionList
impl CopyingHelper for PHCollectionList
Sourcetype Result = PHCollectionList
type Result = PHCollectionList
Self if the type has no
immutable counterpart. Read moreSourceimpl Debug for PHCollectionList
impl Debug for PHCollectionList
Sourceimpl Deref for PHCollectionList
impl Deref for PHCollectionList
Sourceimpl Hash for PHCollectionList
impl Hash for PHCollectionList
Sourceimpl Message for PHCollectionList
impl Message for PHCollectionList
Sourceimpl NSCopying for PHCollectionList
impl NSCopying for PHCollectionList
Sourceimpl NSObjectProtocol for PHCollectionList
impl NSObjectProtocol for PHCollectionList
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
isKindOfClass directly, or cast your objects with AnyObject::downcast_ref